@@ -1,22 +1,25 @@
 import os
 import yaml
+import pathlib
+
 
 class ClusterBase:
-    def __init__(self, config_path="."):
+    def __init__(self, config_path=None):
         """
         Base class for cluster class that generates batch files
 
         Parameters
         ----------
         config_path: str
-            path to the configuration file
+            path to the configuration file, if None user cluster_config
         """
+        if config_path is None:
+            package_path = pathlib.Path(__file__).parent.parent.parent.absolute()
+            config_path = os.path.join(package_path, "cluster_config")
 
         self.config_path = config_path
         self.project_path = None
 
-        # description of where to find configuration file
-
     def set_project_path(self, path):
         self.project_path = path
 
